pub struct PrivateFieldTransform {
config: Config,
}Expand description
Transform that converts TypeScript private fields (#field) to regular properties
VSCode performs this conversion for performance reasons, as private fields using Symbol have more overhead than regular properties.
This module provides the configuration and interface. The actual transform is applied during compilation using the SWC visitor pattern.
Fields
config: ConfigImplementations
Sourceimpl PrivateFieldTransform
impl PrivateFieldTransform
pub fn new() -> Self
pub fn with_config(config: Config) -> Self
Sourcepub fn convert_private_name(&self, name: &str) -> String
pub fn convert_private_name(&self, name: &str) -> String
Convert a private identifier to a regular identifier name
Sourcepub fn is_private_field(&self, name: &str) -> bool
pub fn is_private_field(&self, name: &str) -> bool
Check if a name is a private field